summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/kopetechatwindowstylemanager.h')
-rw-r--r--kopete/kopete/chatwindow/kopetechatwindowstylemanager.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h b/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
index dcc56cf0..712f9bfc 100644
--- a/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
+++ b/kopete/kopete/chatwindow/kopetechatwindowstylemanager.h
@@ -41,9 +41,10 @@ class ChatWindowStyle;
*
* @author MichaĆ«l Larouche <[email protected]>
*/
-class KOPETE_EXPORT ChatWindowStyleManager : public QObject
+class KOPETE_EXPORT ChatWindowStyleManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* StyleList typedef (a TQMap)
@@ -53,14 +54,14 @@ public:
typedef TQMap<TQString, TQString> StyleList;
/**
* The StyleInstallStatus enum. It gives better return value for installStyle().
* - StyleInstallOk : The install went fine.
* - StyleNotValid : The archive didn't contain a valid Chat Window style.
* - StyleNoDirectoryValid : It didn't find a suitable directory to install the theme.
* - StyleCannotOpen : The archive couldn't be openned.
* - StyleUnknow : Unknow error.
*/
- enum StyleInstallStatus { StyleInstallOk = 0, StyleNotValid, StyleNoDirectoryValid, StyleCannotOpen, StyleUnknow };
+ enum StyleInstalltqStatus { StyleInstallOk = 0, StyleNotValid, StyleNoDirectoryValid, StyleCannotOpen, StyleUnknow };
/**
* Destructor.
@@ -90,7 +91,7 @@ public slots:
* Note that you must pass a path to a archive.
*
* @param styleBundlePath Path to the container file to install.
* @return A status code from StyleInstallStatus enum.
*/
int installStyle(const TQString &styleBundlePath);
@@ -136,7 +137,7 @@ private:
* Private constructor(it's a singleton class)
* Call loadStyles() to list all avaiable styles.
*/
- ChatWindowStyleManager(TQObject *parent = 0, const char *name = 0);
+ ChatWindowStyleManager(TQObject *tqparent = 0, const char *name = 0);
static ChatWindowStyleManager *s_self;
@@ -53,14 +54,14 @@ public:
typedef TQMap<TQString, TQString> StyleList;
/**
- * The StyleInstallStatus enum. It gives better return value for installStyle().
+ * The StyleInstalltqStatus enum. It gives better return value for installStyle().
* - StyleInstallOk : The install went fine.
* - StyleNotValid : The archive didn't contain a valid Chat Window style.
@@ -90,7 +91,7 @@ public slots:
*
* @param styleBundlePath Path to the container file to install.
- * @return A status code from StyleInstallStatus enum.
+ * @return A status code from StyleInstalltqStatus enum.
*/
int installStyle(const TQString &styleBundlePath);